Class: EndPointBlank::Commands::GenerateAccessToken

Inherits:
Object
  • Object
show all
Includes:
GenerateAccessTokenMethods
Defined in:
lib/end_point_blank/commands/generate_access_token.rb

Overview

Generates an access token by sending a request to a remote authorization service. Returns the access token from the authorization service or nil if an error occurs.

Method Summary

Methods included from GenerateAccessTokenMethods

included